@@ -1,26 +1,4 @@
-(**************************************************************************)
-(*                Lablgtk                                                 *)
-(*                                                                        *)
-(*    This program is free software; you can redistribute it              *)
-(*    and/or modify it under the terms of the GNU Library General         *)
-(*    Public License as published by the Free Software Foundation         *)
-(*    version 2, with the exception described in file COPYING which       *)
-(*    comes with the library.                                             *)
-(*                                                                        *)
-(*    This program is distributed in the hope that it will be useful,     *)
-(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
-(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
-(*    GNU Library General Public License for more details.                *)
-(*                                                                        *)
-(*    You should have received a copy of the GNU Library General          *)
-(*    Public License along with this program; if not, write to the        *)
-(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
-(*    Boston, MA 02111-1307  USA                                          *)
-(*                                                                        *)
-(*                                                                        *)
-(**************************************************************************)
-
-(* $Id$ *)
+(* $Id: gButton.ml,v 1.33 2004/06/01 12:06:42 oandrieu Exp $ *)
 
 open Gaux
 open Gobject
@@ -34,16 +12,12 @@ open GContainer
 class button_skel obj = object (self)
   inherit bin obj
   inherit button_props
+  method private obj = obj
   method clicked () = Button.clicked obj
   method grab_default () =
     set Widget.P.can_default obj true;
     set Widget.P.has_default obj true
   method event = new GObj.event_ops obj
-
-  method unset_image () =
-    Gobject.Property.set_dyn obj 
-      GtkButtonProps.Button.P.image.Gobject.name
-      (`OBJECT None)
 end
 
 class button_signals obj = object
@@ -103,6 +77,7 @@ end
 class color_button obj = object
   inherit button_skel obj
   inherit color_button_props
+  method private obj = obj
   method connect = new color_button_signals obj
 end
 
@@ -118,6 +93,7 @@ end
 class font_button obj = object
   inherit button_skel obj
   inherit font_button_props
+  method private obj = obj
   method connect = new font_button_signals obj
 end
 
@@ -312,32 +288,3 @@ let radio_tool_button ?group =
     (may_cons RadioToolButton.P.group 
        (Gaux.may_map (fun g -> g#group) group)
        [])
-
-class menu_tool_button obj = object
-  inherit tool_button obj
-  method menu = get MenuToolButton.P.menu obj
-  method set_menu = set MenuToolButton.P.menu obj
-  method set_arrow_tooltip (t : GData.tooltips) =
-    MenuToolButton.set_arrow_tooltip obj t#as_tooltips
-end
-
-let menu_tool_button ?menu =
-  tool_button_params 
-    (fun pl -> new menu_tool_button (MenuToolButton.create pl))
-    (may_cons MenuToolButton.P.menu
-       (Gaux.may_map (fun m -> m#as_menu) menu)
-       [])
-    
-class link_button obj = object
-  inherit button_skel obj
-  inherit link_button_props
-end
-
-let link_button ?label =
-  pack_return 
-    (fun uri -> new link_button 
-       (match label with 
-        | None -> LinkButton.create uri
-        | Some s -> LinkButton.create_with_label uri s))
-
-
