@@ -1,26 +1,4 @@
-(**************************************************************************)
-(*                Lablgtk                                                 *)
-(*                                                                        *)
-(*    This program is free software; you can redistribute it              *)
-(*    and/or modify it under the terms of the GNU Library General         *)
-(*    Public License as published by the Free Software Foundation         *)
-(*    version 2, with the exception described in file COPYING which       *)
-(*    comes with the library.                                             *)
-(*                                                                        *)
-(*    This program is distributed in the hope that it will be useful,     *)
-(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
-(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
-(*    GNU Library General Public License for more details.                *)
-(*                                                                        *)
-(*    You should have received a copy of the GNU Library General          *)
-(*    Public License along with this program; if not, write to the        *)
-(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
-(*    Boston, MA 02111-1307  USA                                          *)
-(*                                                                        *)
-(*                                                                        *)
-(**************************************************************************)
-
-(* $Id$ *)
+(* $Id: gMisc.mli,v 1.42 2005/01/03 23:49:26 oandrieu Exp $ *)
 
 open Gtk
 open GObj
@@ -69,55 +47,6 @@ val statusbar :
   ?height:int ->
   ?packing:(widget -> unit) -> ?show:bool -> unit -> statusbar
 
-(** {3 Status icon} *)
-
-(** @gtkdoc gtk GtkStatusIcon *)
-class status_icon_signals : Gtk.status_icon Gobject.obj ->
-  object
-    method activate : callback:(unit -> unit) -> GtkSignal.id
-    method popup_menu : callback:(int -> int -> unit) -> GtkSignal.id
-    method size_changed : callback:(int -> unit) -> GtkSignal.id
-    method notify_blinking : callback:(bool -> unit) -> GtkSignal.id
-    method notify_screen : callback:(Gdk.screen -> unit) -> GtkSignal.id
-    method notify_visible : callback:(bool -> unit) -> GtkSignal.id
-  end
-
-(** Display an icon in the system tray.
-  @gtkdoc gtk GtkStatusIcon *)
-class status_icon : Gtk.gtk_status_icon ->
-  object
-    val obj : Gtk.status_icon Gobject.obj
-    method connect : status_icon_signals
-    method blinking : bool
-    method get_icon_name : string
-    method get_pixbuf : GdkPixbuf.pixbuf
-    method screen : Gdk.screen
-    method get_size : int
-    method get_stock : string
-    method visible : bool
-    method is_embedded : bool
-    method set_blinking : bool -> unit
-    method set_from_file : string -> unit
-    method set_from_icon_name : string -> unit
-    method set_from_pixbuf : GdkPixbuf.pixbuf -> unit
-    method set_from_stock : string -> unit
-    method set_screen : Gdk.screen -> unit
-    method set_tooltip : string -> unit
-    method set_visible : bool -> unit
-  end
-
-val status_icon :
-  ?screen:Gdk.screen -> ?visible:bool -> ?blinking:bool -> unit -> status_icon
-val status_icon_from_pixbuf :
-  ?screen:Gdk.screen -> ?visible:bool -> ?blinking:bool -> GdkPixbuf.pixbuf -> status_icon
-val status_icon_from_file :
-  ?screen:Gdk.screen -> ?visible:bool -> ?blinking:bool -> string -> status_icon
-val status_icon_from_stock :
-  ?screen:Gdk.screen -> ?visible:bool -> ?blinking:bool -> string -> status_icon
-val status_icon_from_icon_name :
-  ?screen:Gdk.screen -> ?visible:bool -> ?blinking:bool -> string -> status_icon
-
-
 (** {3 Calendar} *)
 
 (** @gtkdoc gtk GtkCalendar *)
@@ -134,9 +63,6 @@ class calendar_signals : 'a obj ->
     method next_year : callback:(unit -> unit) -> GtkSignal.id
     method prev_month : callback:(unit -> unit) -> GtkSignal.id
     method prev_year : callback:(unit -> unit) -> GtkSignal.id
-    method notify_day : callback:(int -> unit) -> GtkSignal.id
-    method notify_month : callback:(int -> unit) -> GtkSignal.id
-    method notify_year : callback:(int -> unit) -> GtkSignal.id
   end
 
 (** Display a calendar and/or allow the user to select a date
@@ -175,10 +101,10 @@ val calendar :
 
 (** A widget for custom user interface elements
     @gtkdoc gtk GtkDrawingArea *)
-class drawing_area : ([> Gtk.drawing_area] as 'a) obj ->
+class drawing_area : Gtk.drawing_area obj ->
   object
     inherit GObj.widget_full
-    val obj : 'a obj
+    val obj : Gtk.drawing_area obj
     method event : event_ops
     method set_size : width:int -> height:int -> unit
   end
@@ -189,39 +115,6 @@ val drawing_area :
   ?height:int ->
   ?packing:(widget -> unit) -> ?show:bool -> unit -> drawing_area
 
-(** {3 Curve} *)
-
-(** Allows direct editing of a curve
-    @gtkdoc gtk GtkCurve *)
-class curve : Gtk.curve obj ->
-  object
-    inherit drawing_area
-    val obj : Gtk.curve obj
-    method reset : unit -> unit
-    method set_gamma : int -> unit
-    method set_vector : float array -> unit
-    method get_vector : int -> float array
-    method curve_type : GtkEnums.curve_type
-    method max_x : float
-    method max_y : float
-    method min_x : float
-    method min_y : float
-    method set_curve_type : GtkEnums.curve_type -> unit
-    method set_max_x : float -> unit
-    method set_max_y : float -> unit
-    method set_min_x : float -> unit
-    method set_min_y : float -> unit
-  end
-
-(** @gtkdoc gtk GtkCurve *)
-val curve :
-  ?width:int -> ?height:int ->
-  ?curve_type:GtkEnums.curve_type ->
-  ?max_x:float -> ?max_y:float ->
-  ?min_x:float -> ?min_y:float ->
-  ?packing:(widget -> unit) -> ?show:bool -> unit -> curve
-
-
 (** {3 Misc. Widgets} *)
 
 (** A base class for widgets with alignments and padding
@@ -266,9 +159,8 @@ val arrow :
   ?height:int ->
   ?packing:(widget -> unit) -> ?show:bool -> unit -> arrow
 
-type image_type =
-  [ `EMPTY | `PIXMAP | `IMAGE | `PIXBUF | `STOCK | `ICON_SET | `ANIMATION
-  | `ICON_NAME | `GICON ]
+type image_type = 
+  [ `EMPTY | `PIXMAP | `IMAGE | `PIXBUF | `STOCK | `ICON_SET | `ANIMATION ]
 
 (** A widget displaying an image
     @gtkdoc gtk GtkImage *)
@@ -277,7 +169,6 @@ class image : 'a obj ->
     inherit misc
     constraint 'a = [> Gtk.image]
     val obj : 'a obj
-    method clear : unit -> unit (** since Gtk 2.8 *)
     method storage_type : image_type
     method set_image : Gdk.image -> unit
     method set_pixmap : GDraw.pixmap -> unit
@@ -287,12 +178,10 @@ class image : 'a obj ->
     method set_stock : GtkStock.id -> unit
     method set_icon_set : icon_set -> unit
     method set_icon_size : Tags.icon_size -> unit
-    method set_pixel_size : int -> unit
     method image : Gdk.image
     method pixmap : GDraw.pixmap
     method mask : Gdk.bitmap option
     method pixbuf : GdkPixbuf.pixbuf
-    method pixel_size : int
     method stock : GtkStock.id
     method icon_set : icon_set
     method icon_size : Tags.icon_size
@@ -303,7 +192,6 @@ val image :
   ?file:string ->
   ?image:Gdk.image ->
   ?pixbuf:GdkPixbuf.pixbuf ->
-  ?pixel_size:int ->
   ?pixmap:Gdk.pixmap ->
   ?mask:Gdk.bitmap ->
   ?stock:GtkStock.id ->
@@ -407,7 +295,7 @@ val label_cast : < as_widget : 'a obj ; .. > -> label
 
 (** {4 Tips query} *)
 
-(** @gtkdoc gtk GtkTipsQuery
+(** @gtkdoc gtk GtkTipsQuery 
     @deprecated . *)
 class tips_query_signals : Gtk.tips_query obj ->
   object
@@ -421,10 +309,6 @@ class tips_query_signals : Gtk.tips_query obj ->
       callback:(widget option -> text:string -> privat:string ->
                 GdkEvent.Button.t -> bool) ->
       GtkSignal.id
-    method notify_caller : callback:(GObj.widget option -> unit) -> GtkSignal.id
-    method notify_emit_always : callback:(bool -> unit) -> GtkSignal.id
-    method notify_label_inactive : callback:(string -> unit) -> GtkSignal.id
-    method notify_label_no_tip : callback:(string -> unit) -> GtkSignal.id
   end
 
 (** Displays help about widgets in the user interface
