@@ -1,81 +1,34 @@
-/**************************************************************************/
-/*                Lablgtk                                                 */
-/*                                                                        */
-/*    This program is free software; you can redistribute it              */
-/*    and/or modify it under the terms of the GNU Library General         */
-/*    Public License as published by the Free Software Foundation         */
-/*    version 2, with the exception described in file COPYING which       */
-/*    comes with the library.                                             */
-/*                                                                        */
-/*    This program is distributed in the hope that it will be useful,     */
-/*    but WITHOUT ANY WARRANTY; without even the implied warranty of      */
-/*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       */
-/*    GNU Library General Public License for more details.                */
-/*                                                                        */
-/*    You should have received a copy of the GNU Library General          */
-/*    Public License along with this program; if not, write to the        */
-/*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         */
-/*    Boston, MA 02111-1307  USA                                          */
-/*                                                                        */
-/*                                                                        */
-/**************************************************************************/
-
-/* $Id$ */
+/* $Id: wrappers.h,v 1.63 2005/06/02 00:20:06 garrigue Exp $ */
 
 #ifndef _wrappers_
 #define _wrappers_
 
 /* Yell if a caml callback raised an exception */
 #define CAML_EXN_LOG(name) g_critical("%s: callback raised an exception", name)
-#define CAML_EXN_LOG_VERBOSE(name,exn) g_critical("%s: callback raised exception %s", name, format_caml_exception(Extract_exception(exn)))
 
 #include <caml/misc.h>
 #include <caml/mlvalues.h>
 #include <caml/fail.h>
 #include <caml/custom.h>
-#include <caml/minor_gc.h>
-#define Is_young_block(v) \
-  (Is_block(v) && (value*)(v) < caml_young_end && (value*)(v) > caml_young_start)
+CAMLextern char *young_start, *young_end; /* from minor_gc.h */
 
-#ifndef Bytes_val
-#define Bytes_val String_val
-#endif
-
-CAMLexport value copy_memblock_indirected (void *src, asize_t size);
+value copy_memblock_indirected (void *src, asize_t size);
 value alloc_memblock_indirected (asize_t size);
-CAMLexport value ml_alloc_custom(struct custom_operations * ops,
-                                 uintnat size, mlsize_t mem, mlsize_t max);
 CAMLprim value ml_some (value);
 value ml_cons (value, value);
-CAMLexport void ml_raise_null_pointer (void) Noreturn;
-CAMLexport value Val_pointer (void *);
+void ml_raise_null_pointer (void) Noreturn;
+value Val_pointer (void *);
 CAMLprim value copy_string_check (const char*);
 value copy_string_or_null (const char *);
-value Val_option_string (const char *s);
-
-value string_list_of_strv (const char * const *v);
-value string_list_of_strv2 (char **v);
-char ** strv_of_string_list (value list);
 
 CAMLprim value *ml_global_root_new (value v);
-CAMLexport void ml_global_root_destroy (void *data);
-
-/* Pointer conversions */
-#define Pointer_val(val) ((void*)Field(val,1))
-#define Store_pointer(val,p) (Field(val,1)=Val_bp(p))
-#define MLPointer_val(val) \
-        ((int)Field(val,1) == 2 ? &Field(val,2) : (void*)Field(val,1))
-
-#define Val_addr(ptr) (1+(value)ptr)
-#define Addr_val(val) ((void*)(val-1))
+void ml_global_root_destroy (void *data);
 
 /* enums <-> polymorphic variants */
 typedef struct { value key; int data; } lookup_info;
-#define Val_lookup_info(v) Val_pointer((void*)v)
-#define Lookup_info_val(v) ((const lookup_info*)Pointer_val(v))
-CAMLexport value ml_lookup_from_c (const lookup_info table[], int data);
-CAMLexport int ml_lookup_to_c (const lookup_info table[], value key);
-CAMLexport value ml_lookup_flags_getter (const lookup_info table[], int data);
+value ml_lookup_from_c (const lookup_info table[], int data);
+int ml_lookup_to_c (const lookup_info table[], value key);
+value ml_lookup_flags_getter (const lookup_info table[], int data);
 
 /* Compatibility */
 #include <gtk/gtkversion.h>
@@ -88,38 +41,18 @@ CAMLexport value ml_lookup_flags_getter (const lookup_info table[], int data);
 #if GTK_CHECK_VERSION(2,5,3) && !defined(DISABLE_GTK26)
 #define HASGTK26
 #endif
-#if GTK_CHECK_VERSION(2,8,0) && !defined(DISABLE_GTK28)
-#define HASGTK28
-#endif
-#if GTK_CHECK_VERSION(2,10,0) && !defined(DISABLE_GTK210)
-#define HASGTK210
-#endif
-#if GTK_CHECK_VERSION(2,12,0) && !defined(DISABLE_GTK212)
-#define HASGTK212
-#endif
 
 /* Wrapper generators */
 
-#define Unsupported_22(cname) \
+#define Unsupported(cname) \
 CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.2"); }
-#define Unsupported Unsupported_22
+{ failwith(#cname " unsupported in Gtk 2.x < 2.2"); return Val_unit; }
 #define Unsupported_24(cname) \
 CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.4"); }
+{ failwith(#cname " unsupported in Gtk 2.x < 2.4"); return Val_unit; }
 #define Unsupported_26(cname) \
 CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.6"); }
-#define Unsupported_28(cname) \
-CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.8"); }
-
-#define Unsupported_210(cname) \
-CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.10"); }
-#define Unsupported_212(cname) \
-CAMLprim value ml_##cname () \
-{ failwith(#cname " unsupported in Gtk 2.x < 2.12"); }
+{ failwith(#cname " unsupported in Gtk 2.x < 2.6"); return Val_unit; }
 
 #define ID(x) (x)
 
@@ -274,8 +207,7 @@ CAMLprim value cname##_bc (value *argv, int argn) \
 /* parameter conversion */
 #define Bool_ptr(x) ((long) x - 1)
 #define Char_val Int_val
-#define Float_val Double_val
-/* #define Float_val(x) ((float)Double_val(x)) */
+#define Float_val(x) ((float)Double_val(x))
 #define SizedString_val(x) String_val(x), string_length(x)
 
 #define Option_val(val,unwrap,default) \
@@ -297,7 +229,7 @@ CAMLprim value cname##_bc (value *argv, int argn) \
  else if (l <= Max_young_wosize) { int i; ret = alloc_tuple(l); \
    for(i=0;i<l;i++) Field(ret,i) = conv(src[i]); } \
  else { int i; ret = alloc_shr(l,0); \
-   for(i=0;i<l;i++) caml_initialize (&Field(ret,i), conv(src[i])); }
+   for(i=0;i<l;i++) initialize (&Field(ret,i), conv(src[i])); }
 
 #define Make_Val_final_pointer(type, init, final, adv) \
 static void ml_final_##type (value val) \
@@ -307,8 +239,8 @@ static struct custom_operations ml_custom_##type = \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
 CAMLprim value Val_##type (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
-  ret = ml_alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
-  caml_initialize (&Field(ret,1), (value) p); init(p); return ret; }
+  ret = alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
+  initialize (&Field(ret,1), (value) p); init(p); return ret; }
 
 #define Make_Val_final_pointer_ext(type, ext, init, final, adv) \
 static void ml_final_##type##ext (value val) \
@@ -318,8 +250,8 @@ static struct custom_operations ml_custom_##type##ext = \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
 CAMLprim value Val_##type##ext (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
-  ret = ml_alloc_custom (&ml_custom_##type##ext, sizeof(value), adv, 1000); \
-  caml_initialize (&Field(ret,1), (value) p); init(p); return ret; }
+  ret = alloc_custom (&ml_custom_##type##ext, sizeof(value), adv, 1000); \
+  initialize (&Field(ret,1), (value) p); init(p); return ret; }
 
 #define Make_Val_final_pointer_compare(type, init, comp, final, adv) \
 static void ml_final_##type (value val) \
@@ -331,8 +263,16 @@ static struct custom_operations ml_custom_##type = \
   custom_hash_default, custom_serialize_default, custom_deserialize_default };\
 CAMLprim value Val_##type (type *p) \
 { value ret; if (!p) ml_raise_null_pointer(); \
-  ret = ml_alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
-  caml_initialize (&Field(ret,1), (value) p); init(p); return ret; }
+  ret = alloc_custom (&ml_custom_##type, sizeof(value), adv, 1000); \
+  initialize (&Field(ret,1), (value) p); init(p); return ret; }
+
+#define Pointer_val(val) ((void*)Field(val,1))
+#define Store_pointer(val,p) (Field(val,1)=Val_bp(p))
+#define MLPointer_val(val) \
+        (Field(val,1) == 2 ? &Field(val,2) : (void*)Field(val,1))
+
+#define Val_addr(ptr) (1+(value)ptr)
+#define Addr_val(val) ((void*)(val-1))
 
 #define Wosize_asize(x) ((x-1)/sizeof(value)+1)
 #define Wosizeof(x) Wosize_asize(sizeof(x))
@@ -357,15 +297,15 @@ CAMLprim value ml_##name##_##field (value val, value index, value new) \
 #define Make_Flags_val(conv) \
 CAMLprim int Flags_##conv (value list) \
 { int flags = 0L; \
-  while(Is_block(list)){ flags |= conv(Field(list,0)); list = Field(list,1); }\
+  while Is_block(list) { flags |= conv(Field(list,0)); list = Field(list,1); }\
   return flags; }
 
 /* ML value is [flag list option] */
 #define Make_OptFlags_val(conv) \
 CAMLprim int OptFlags_##conv (value list) \
 { int flags = 0L; \
-  if (Is_block(list)) list = Field(list,0); \
-  while(Is_block(list)){ flags |= conv(Field(list,0)); list = Field(list,1); }\
+  if Is_block(list) list = Field(list,0); \
+  while Is_block(list) { flags |= conv(Field(list,0)); list = Field(list,1); }\
   return flags; }
 
 #define Val_copy(val) copy_memblock_indirected (&val, sizeof(val))
@@ -373,8 +313,6 @@ CAMLprim int OptFlags_##conv (value list) \
 #define Val_optstring copy_string_or_null
 #define Optstring_val(v) (string_length(v) ? String_val(v) : (char*)NULL)
 #define Val_option(v,f) (v ? ml_some(f(v)) : Val_unit)
-#define Make_Val_option(T) \
-value Val_option_##T(T* v) { return Val_option(v,Val_##T); }
 
 #define Check_null(v) (v ? v : (ml_raise_null_pointer (), v))
 
